==> presto-jdbc-0.285-sources.jar: com/facebook/presto/jdbc/internal/spi/eventlistener/CTEInformation.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.facebook.presto.jdbc.internal.spi.eventlistener;

import com.facebook.presto.jdbc.internal.jackson.annotation.JsonCreator;
import com.facebook.presto.jdbc.internal.jackson.annotation.JsonProperty;

import static java.util.Objects.requireNonNull;

public class CTEInformation
{
    // Name of the common table expression as used in the query
    private final String cteName;
    //number of references of the CTE in the query
    private int numberOfReferences;
    private final boolean isView;

    @JsonCreator
    public CTEInformation(
            @JsonProperty("cteName") String cteName,
            @JsonProperty("numberOfReferences") int numberOfReferences,
            @JsonProperty("isView") boolean isView)
    {
        this.cteName = requireNonNull(cteName, "cteName is null");
        this.numberOfReferences = numberOfReferences;
        this.isView = isView;
    }

    @JsonProperty
    public String getCteName()
    {
        return cteName;
    }

    @JsonProperty
    public int getNumberOfReferences()
    {
        return numberOfReferences;
    }

    @JsonProperty
    public boolean getIsView()
    {
        return isView;
    }

    public void incrementReferences()
    {
        numberOfReferences++;
    }
}

==> presto-jdbc-0.286-sources.jar: com/facebook/presto/jdbc/internal/spi/eventlistener/CTEInformation.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.facebook.presto.jdbc.internal.spi.eventlistener;

import com.facebook.presto.jdbc.internal.jackson.annotation.JsonCreator;
import com.facebook.presto.jdbc.internal.jackson.annotation.JsonProperty;

import static java.util.Objects.requireNonNull;

public class CTEInformation
{
    // Name of the common table expression as used in the query
    private final String cteName;
    //number of references of the CTE in the query
    private int numberOfReferences;
    private final boolean isView;
    private final boolean isMaterialized;

    @JsonCreator
    public CTEInformation(
            @JsonProperty("cteName") String cteName,
            @JsonProperty("numberOfReferences") int numberOfReferences,
            @JsonProperty("isView") boolean isView,
            @JsonProperty("isMaterialized") boolean isMaterialized)
    {
        this.cteName = requireNonNull(cteName, "cteName is null");
        this.numberOfReferences = numberOfReferences;
        this.isView = isView;
        this.isMaterialized = isMaterialized;
    }

    @JsonProperty
    public String getCteName()
    {
        return cteName;
    }

    @JsonProperty
    public boolean isMaterialized()
    {
        return isMaterialized;
    }

    @JsonProperty
    public int getNumberOfReferences()
    {
        return numberOfReferences;
    }

    @JsonProperty
    public boolean getIsView()
    {
        return isView;
    }

    public void incrementReferences()
    {
        numberOfReferences++;
    }
}
